@@ -1,7 +1,7 @@
 package WWW::Google::Contacts::Roles::List;
 
 BEGIN {
-    $WWW::Google::Contacts::Roles::List::VERSION = '0.13';
+    $WWW::Google::Contacts::Roles::List::VERSION = '0.14';
 }
 
 use Moose::Role;
@@ -75,7 +75,7 @@ sub next {
     my $next = $self->elements->[ $self->pointer ];
     $self->pointer( $self->pointer + 1 );
     my $class = $self->element_class;
-    return $class->new()->set_from_server($next);
+    return $class->new( server => $self->server )->set_from_server($next);
 }
 
 sub _build_elements {
